==> xJdfLib-0.5-sources.jar: org/cip4/lib/xjdf/schema/ParameterType.java <==

package org.cip4.lib.xjdf.schema;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ParameterType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ParameterType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ParameterType")
@XmlSeeAlso({
    GlueLine.class,
    DigitalDeliveryParams.class,
    DigitalPrintingParams.class,
    ShapeDefProductionParams.class,
    CasingInParams.class,
    HoleList.class,
    BarcodeReproParams.class,
    PreflightReportRulePool.class,
    TransferFunctionControl.class,
    RefAnchor.class,
    CoilBindingParams.class,
    LayoutElementProductionParams.class,
    DBRules.class,
    QualityControlResult.class,
    ShapeDef.class,
    CustomerInfo.class,
    AutomatedOverPrintParams.class,
    ApprovalParams.class,
    HeadBandApplicationParams.class,
    ProductionPath.class,
    ManualLaborParams.class,
    InsertingParams.class,
    HoleMakingParams.class,
    VarnishingParams.class,
    ShapeCuttingParams.class,
    PDLCreationParams.class,
    CylinderLayoutPreparationParams.class,
    CutBlock.class,
    VerificationParams.class,
    ProofingParams.class,
    DeviceNSpace.class,
    Contact.class,
    DensityMeasuringField.class,
    ComChannel.class,
    RunList.class,
    GlueApplication.class,
    DBSchema.class,
    Trigger.class,
    Hole.class,
    ThreadSealingParams.class,
    BendingParams.class,
    FontPolicy.class,
    TransferCurvePool.class,
    InsertSheet.class,
    QualityControlParams.class,
    ElementColorParams.class,
    PreflightReport.class,
    ImageReplacementParams.class,
    JobField.class,
    CreasingParams.class,
    ImageSetterParams.class,
    GluingParams.class,
    DBSelection.class,
    InterpretingParams.class,
    PreflightParams.class,
    BlockPreparationParams.class,
    TransferCurve.class,
    LongitudinalRibbonOperationParams.class,
    Address.class,
    Fold.class,
    DieLayout.class,
    FontParams.class,
    ContactCopyParams.class,
    Color.class,
    NumberingParams.class,
    CylinderLayout.class,
    ByteMap.class,
    SaddleStitchingParams.class,
    ShrinkingParams.class,
    SpinePreparationParams.class,
    FitPolicy.class,
    DeviceMark.class,
    ImageCompressionParams.class,
    EndSheetGluingParams.class,
    StrappingParams.class,
    ColorantAlias.class,
    DBMergeParams.class,
    Person.class,
    ScavengerArea.class,
    IdentificationField.class,
    PerforatingParams.class,
    FoldingParams.class,
    BinderySignature.class,
    PSToPDFConversionParams.class,
    InterpretedPDLData.class,
    Preview.class,
    AssetListCreationParams.class,
    LayoutPreparationParams.class,
    StripBindingParams.class,
    CoverApplicationParams.class,
    CIELABMeasuringField.class,
    PlasticCombBindingParams.class,
    NodeInfo.class,
    RenderingParams.class,
    FoldOperation.class,
    FileSpec.class,
    ConventionalPrintingParams.class,
    PackingParams.class,
    Layout.class,
    CaseMakingParams.class,
    StackingParams.class,
    BarcodeCompParams.class,
    TrappingParams.class,
    PalletizingParams.class,
    JacketingParams.class,
    RegisterMark.class,
    HoleLine.class,
    PlateCopyParams.class,
    WrappingParams.class,
    EmbossingParams.class,
    SeparationControlParams.class,
    ApprovalSuccess.class,
    PDFToPSConversionParams.class,
    ColorMeasurementConditions.class,
    ObjectResolution.class,
    Media.class,
    InkZoneProfile.class,
    ThreadSewingParams.class,
    CuttingParams.class,
    CollectingParams.class,
    StitchingParams.class,
    ScreeningParams.class,
    LaminatingParams.class,
    PreviewGenerationParams.class,
    BufferParams.class,
    Company.class,
    InkZoneCalculationParams.class,
    AdhesiveBindingParams.class,
    DevelopingParams.class,
    SpineTapingParams.class,
    SideSewingParams.class,
    PageList.class,
    Assembly.class,
    Shape.class,
    MediaSource.class,
    TrapRegion.class,
    ChannelBindingParams.class,
    ContentList.class,
    GatheringParams.class,
    PreflightAnalysis.class,
    ColorControlStrip.class,
    BundlingParams.class,
    DieLayoutProductionParams.class,
    DeliveryParams.class,
    FormatConversionParams.class,
    ResourceDefinitionParams.class,
    PrintRollingParams.class,
    PDLResourceAlias.class,
    PrintCondition.class,
    Tile.class,
    ColorCorrectionParams.class,
    ColorSpaceConversionParams.class,
    TrimmingParams.class,
    FeedingParams.class,
    CutMark.class,
    ExternalImpositionTemplate.class,
    DividingParams.class,
    OrderingParams.class,
    RingBindingParams.class,
    PreflightInventory.class,
    LabelingParams.class,
    BoxPackingParams.class,
    WireCombBindingParams.class,
    BoxFoldingParams.class,
    ColorantControl.class,
    LayoutShift.class,
    WebInlineFinishingParams.class,
    PreflightProfile.class,
    ScanParams.class,
    TrappingDetails.class
})
public abstract class ParameterType implements Serializable
{


}

==> xJdfLib-0.6-sources.jar: org/cip4/lib/xjdf/schema/ParameterType.java <==

package org.cip4.lib.xjdf.schema;

import java.io.Serializable;
import javax.annotation.Generated;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * <p>Java class for ParameterType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ParameterType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ParameterType")
@XmlSeeAlso({
    Address.class,
    CustomerInfo.class,
    ComChannel.class,
    NodeInfo.class,
    Shape.class,
    Trigger.class,
    Preview.class,
    BlockPreparationParams.class,
    BoxPackingParams.class,
    BufferParams.class,
    CaseMakingParams.class,
    CasingInParams.class,
    ColorMeasurementConditions.class,
    ContactCopyParams.class,
    CoverApplicationParams.class,
    CreasingParams.class,
    CuttingParams.class,
    DevelopingParams.class,
    DeviceMark.class,
    EmbossingParams.class,
    EndSheetGluingParams.class,
    FitPolicy.class,
    FormatConversionParams.class,
    GatheringParams.class,
    GluingParams.class,
    HeadBandApplicationParams.class,
    GlueLine.class,
    InsertingParams.class,
    InterpretingParams.class,
    JacketingParams.class,
    JobField.class,
    LabelingParams.class,
    LaminatingParams.class,
    LayoutPreparationParams.class,
    NumberingParams.class,
    PalletizingParams.class,
    PerforatingParams.class,
    PreflightAnalysis.class,
    RefAnchor.class,
    ScavengerArea.class,
    ShapeCuttingParams.class,
    ShrinkingParams.class,
    TransferCurvePool.class,
    InsertSheet.class,
    SpinePreparationParams.class,
    SpineTapingParams.class,
    StackingParams.class,
    StrappingParams.class,
    ThreadSealingParams.class,
    TransferFunctionControl.class,
    VarnishingParams.class,
    VerificationParams.class,
    WrappingParams.class,
    LooseBindingParams.class,
    FileSpec.class,
    ApprovalParams.class,
    ApprovalSuccess.class,
    Assembly.class,
    AutomatedOverPrintParams.class,
    BarcodeCompParams.class,
    BarcodeReproParams.class,
    BendingParams.class,
    BinderySignature.class,
    BoxFoldingParams.class,
    ByteMap.class,
    CIELABMeasuringField.class,
    CollectingParams.class,
    Color.class,
    ColorantAlias.class,
    ColorantControl.class,
    ColorControlStrip.class,
    Company.class,
    Contact.class,
    Content.class,
    ConventionalPrintingParams.class,
    CutBlock.class,
    DeliveryParams.class,
    DensityMeasuringField.class,
    RunList.class,
    DeviceNSpace.class,
    DieLayout.class,
    DieLayoutProductionParams.class,
    DigitalPrintingParams.class,
    ElementColorParams.class,
    ExternalImpositionTemplate.class,
    FeedingParams.class,
    FoldOperation.class,
    FontParams.class,
    FontPolicy.class,
    IdentificationField.class,
    ImageCompressionParams.class,
    ImageReplacementParams.class,
    ImageSetterParams.class,
    InterpretedPDLData.class,
    Layout.class,
    LayoutElementProductionParams.class,
    LayoutShift.class,
    LongitudinalRibbonOperationParams.class,
    ManualLaborParams.class,
    MediaSource.class,
    ObjectResolution.class,
    OrderingParams.class,
    PackingParams.class,
    PDLCreationParams.class,
    Person.class,
    PlateCopyParams.class,
    PreflightParams.class,
    PreflightReport.class,
    PrintRollingParams.class,
    ProductionPath.class,
    ProofingParams.class,
    QualityControlParams.class,
    QualityControlResult.class,
    RegisterMark.class,
    ResourceDefinitionParams.class,
    ShapeDef.class,
    SeparationControlParams.class,
    ShapeDefProductionParams.class,
    Tile.class,
    TransferCurve.class,
    TrapRegion.class,
    BundlingParams.class,
    CutMark.class,
    Fold.class,
    FoldingParams.class,
    GlueApplication.class,
    HoleMakingParams.class,
    SaddleStitchingParams.class,
    SideSewingParams.class,
    StitchingParams.class,
    ThreadSewingParams.class,
    TrimmingParams.class,
    WebInlineFinishingParams.class,
    AssetListCreationParams.class,
    ColorCorrectionParams.class,
    ColorSpaceConversionParams.class,
    DigitalDeliveryParams.class,
    InkZoneCalculationParams.class,
    InkZoneProfile.class,
    PDFToPSConversionParams.class,
    PDLResourceAlias.class,
    PreviewGenerationParams.class,
    PSToPDFConversionParams.class,
    RenderingParams.class,
    ScanParams.class,
    ScreeningParams.class,
    TrappingDetails.class,
    TrappingParams.class,
    PrintCondition.class
})
@Generated(value = "com.sun.tools.xjc.Driver", date = "2016-04-14T04:49:07+02:00", comments = "JAXB RI v2.2.11")
public abstract class ParameterType implements Serializable, Equals, HashCode
{


    @Generated(value = "com.sun.tools.xjc.Driver", date = "2016-04-14T04:49:07+02:00", comments = "JAXB RI v2.2.11")
    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof ParameterType)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        return true;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", date = "2016-04-14T04:49:07+02:00", comments = "JAXB RI v2.2.11")
    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    @Generated(value = "com.sun.tools.xjc.Driver", date = "2016-04-14T04:49:07+02:00", comments = "JAXB RI v2.2.11")
    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = 1;
        return currentHashCode;
    }

    @Generated(value = "com.sun.tools.xjc.Driver", date = "2016-04-14T04:49:07+02:00", comments = "JAXB RI v2.2.11")
    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

}
